@@ -1,7 +1,10 @@
 import pandas as pd
 from sklearn.base import BaseEstimator
 
-from hcrystalball.utils import check_X_y, enforce_y_type, check_fit_before_predict, get_estimator_name
+from hcrystalball.utils import check_X_y
+from hcrystalball.utils import enforce_y_type
+from hcrystalball.utils import check_fit_before_predict
+from hcrystalball.utils import get_estimator_name
 from hcrystalball.exceptions import DuplicatedModelNameError
 
 
