@@ -18,11 +18,11 @@ def get_gridsearch(
     scoring="neg_mean_absolute_error",
     country_code_column=None,
     country_code=None,
-    sklearn_models=False,
+    sklearn_models=True,
     sklearn_models_optimize_for_horizon=False,
     autosarimax_models=False,
     autoarima_dict=None,
-    prophet_models=True,
+    prophet_models=False,
     tbats_models=False,
     exp_smooth_models=False,
     average_ensembles=False,
@@ -329,12 +329,10 @@ def get_gridsearch(
             {
                 "model": [
                     SimpleSmoothingWrapper(
-                        freq=frequency,
                         clip_predictions_lower=clip_predictions_lower,
                         clip_predictions_upper=clip_predictions_upper,
                     ),
                     HoltSmoothingWrapper(
-                        freq=frequency,
                         clip_predictions_lower=clip_predictions_lower,
                         clip_predictions_upper=clip_predictions_upper,
                     ),
